This function returns morphodata object, where each population is used as the operational taxonomic unit (OTUs),
thus is represented by single ``individual'' (row) with average values for each character.
Note that when using populations as OTUs, they are handled with the same weight in all analyses
(disregarding population size, within-population variation, etc.)